@@ -25,6 +25,7 @@ CONFIG_DEFAULTS = {
     'num_persistent_connections': '100',
     'num_connections_per_session': '10',
     'connection_timeout': '240',
+    'extra_headers': '',
     'verbose': 'false',
 
     'log_statsd_host': '',
@@ -99,7 +100,8 @@ def makeService(options):
     from swftp.sftp.server import SwiftSFTPRealm, SwiftSSHServerTransport, \
         SwiftSSHConnection
     from swftp.auth import SwiftBasedAuthDB
-    from swftp.utils import log_runtime_info, GLOBAL_METRICS
+    from swftp.utils import (
+        log_runtime_info, GLOBAL_METRICS, parse_key_value_config)
 
     c = get_config(options['config_file'], options)
 
@@ -149,6 +151,7 @@ def makeService(options):
         global_max_concurrency=c.getint('sftp', 'num_persistent_connections'),
         max_concurrency=c.getint('sftp', 'num_connections_per_session'),
         timeout=c.getint('sftp', 'connection_timeout'),
+        extra_headers=parse_key_value_config(c.get('sftp', 'extra_headers')),
         verbose=c.getboolean('sftp', 'verbose'))
 
     sftpportal = Portal(SwiftSFTPRealm())
